4.32. umbra.managers.layoutsManager — Umbra 1.0.9 documentation

# 4.32. umbra.managers.layoutsManager

layoutsManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `LayoutsManager` and `Layout` classes.

Others:

## 4.32.1. Module Attributes

`umbra.managers.layoutsManager.` `LOGGER`

## 4.32.2. Classes

class `umbra.managers.layoutsManager.` `Layout`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for `LayoutsManager` class layout.

  Initializes the class.

  Parameters: | **kwargs (dict) – name, identity, shortcut.

class `umbra.managers.layoutsManager.` `LayoutsManager`(parent=None)

  Bases: `PyQt4.QtCore.QObject`

  Defines the Application layouts manager.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent.

  `layoutRestored`

    This signal is emited by the `LayoutsManager` class when the current layout has been restored. ( pyqtSignal )

    Returns: | Current layout.
    Return type: | unicode

  `layoutStored`

    This signal is emited by the `LayoutsManager` class when the current layout has been stored. ( pyqtSignal )

    Returns: | Current layout.
    Return type: | unicode

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | Preferences

  `layouts`

    Property for self.__layouts attribute.

    Returns: | self.__layouts.
    Return type: | dict

  `currentLayout`

    Property for self.__currentLayout attribute.

    Returns: | self.__currentLayout.
    Return type: | tuple or list

  `restoreGeometryOnLayoutChange`

    Property for self.__restoreGeometryOnLayoutChange attribute.

    Returns: | self.__restoreGeometryOnLayoutChange.
    Return type: | bool

  `get`(layout, default=None)

    Returns given layout value.

    Parameters: | layout (unicode) – Layout name. default (object) – Default value if layout is not found.
    Returns: | Action.
    Return type: | QAction

  `listLayouts`()

    Returns the registered layouts.

    Returns: | Registered layouts.
    Return type: | list

  `isLayoutRegistered`(name)

    Returns if the given layout name is registered.

    Parameters: | name (unicode) – Layout name.
    Returns: | Is layout registered.
    Return type: | bool

  `registerLayout`(name, layout)

    Registers given layout.

    Parameters: | name (unicode) – Layout name. layout (Layout) – Layout object.
    Returns: | Method success.
    Return type: | bool

  `unregisterLayout`(name)

    Unregisters given layout.

    Parameters: | name (unicode) – Layout name. layout (Layout) – Layout object.
    Returns: | Method success.
    Return type: | bool

  `restoreLayout`(name, *args)

    Restores given layout.

    Parameters: | name (unicode) – Layout name. *args (*) – Arguments.
    Returns: | Method success.
    Return type: | bool

  `storeLayout`(name, *args)

    Stores given layout.

    Parameters: | name (unicode) – Layout name. *args (*) – Arguments.
    Returns: | Method success.
    Return type: | bool

  `restoreStartupLayout`()

    Restores the startup layout.

    Returns: | Method success.
    Return type: | bool

  `storeStartupLayout`()

    Stores the startup layout.

    Returns: | Method success.
    Return type: | bool